# Data Structures

The subpackage that contains all implemented data structures in `andz`.

A few interesting data structures which may be implemented in the future.

## Graphs

- Adjacency List
- Adjacency Matrix
- Directed Graph
- Undirected Graph

## Linear Data Structures

### Arrays

- Matrix
- Sparse Matrix
- Gap Buffer

### Lists

- [Skip list](https://brilliant.org/wiki/skip-lists/)
- [Doubly connected edge list](https://en.wikipedia.org/wiki/Doubly_connected_edge_list)

## Trees

### Binary Trees

- AVL Tree
- Splay Tree
- WAVL Tree

### B-trees

- B-tree
- 2-3 Tree

### Heaps

- Fibonacci Heap
- Binomial Heap

### Trees and Tries

- Trie
- Radix Tree
- Suffix Tree

### Multi-way Trees

- Van Emde Boas Tree

### Space-partitioning Trees

- K-d Tree

## Probabilistic Data Structures

- Bloom filter

---

An article listing other possibly interesting data structures can be found at the 
following URL [https://en.wikipedia.org/wiki/List_of_data_structures](https://en.wikipedia.org/wiki/List_of_data_structures).